package com.ruoyi.post.service;

import com.ruoyi.post.domain.PostPublisher;

import java.util.List;

/**
 * @Author HuiANan
 * @Date 2023/1/25 20:18
 * @Exegesis:
 */
public interface IPostPublisherService
{
    /**
     * 查询邮贝发行方信息;
     *
     * @param publisherId 邮贝发行方信息;主键
     * @return 邮贝发行方信息;
     */
    public PostPublisher selectPostPublisherByPublisherId(Long publisherId);

    /**
     * 查询邮贝发行方信息;列表
     *
     * @param postPublisher 邮贝发行方信息;
     * @return 邮贝发行方信息;集合
     */
    public List<PostPublisher> selectPostPublisherList(PostPublisher postPublisher);

    /**
     * 新增邮贝发行方信息;
     *
     * @param postPublisher 邮贝发行方信息;
     * @return 结果
     */
    public int insertPostPublisher(PostPublisher postPublisher);

    /**
     * 修改邮贝发行方信息;
     *
     * @param postPublisher 邮贝发行方信息;
     * @return 结果
     */
    public int updatePostPublisher(PostPublisher postPublisher);

    /**
     * 批量删除邮贝发行方信息;
     *
     * @param publisherIds 需要删除的邮贝发行方信息;主键集合
     * @return 结果
     */
    public int deletePostPublisherByPublisherIds(Long[] publisherIds);

    /**
     * 删除邮贝发行方信息;信息
     *
     * @param publisherId 邮贝发行方信息;主键
     * @return 结果
     */
    public int deletePostPublisherByPublisherId(Long publisherId);

    /**
     * 检验发行方名称是否重复
     */
    public String checkPublisherName(PostPublisher postPublisher);

    /**
     * 检验发行方图像是否重复
     */
    public String checkImage(PostPublisher postPublisher);
}